#
# spec file for package sdl12_compat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdl12_compat
%define lname libSDL-1_2-0
%global _lto_cflags %_lto_cflags -ffat-lto-objects
Version:        1.2.68
Release:        1.5
Summary:        SDL-1.2 Compatibility Layer for Simple DirectMedia Layer 2.0
License:        MIT
Group:          Development/Libraries/X11
URL:            https://github.com/libsdl-org/sdl12-compat
Source:         https://github.com/libsdl-org/sdl12-compat/archive/refs/tags/release-%version.tar.gz
Source8:        baselibs.conf
Source9:        %name-rpmlintrc
BuildRequires:  cmake
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(sdl2)

# A list of known apps/issues is at
# docs.google.com/spreadsheets/d/1u8Rq3LVQYYgu28sBuxrZ371QolbiZu5z_LjENc4ddZs/edit

%description
This is the "Simple DirectMedia Layer" library built from sdl12_compat.
it provides a binary and source compatible API for programs written
against SDL 1.2, but it uses SDL 2.0 behind the scenes.

%package -n %lname
Summary:        SDL Graphics Routines for Primitives and Other Support Functions
Group:          System/Libraries
Conflicts:      libSDL-1_2-0
%requires_eq    %(rpm --qf "%%{name}" -qf $(readlink -f %{_libdir}/libSDL2.so))

%description -n %lname
This is the "Simple DirectMedia Layer" library built from sdl12_compat.
it provides a binary and source compatible API for programs written
against SDL 1.2, but it uses SDL 2.0 behind the scenes.

%package devel
Summary:        Libraries, includes and more to develop SDL-1.2 applications
Group:          Development/Libraries/X11
Requires:       %lname = %version
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
Conflicts:      SDL-devel
Provides:       SDL-devel = %version-%release
Provides:       libSDL-devel = %version-%release

%description devel
This package contains files needed for development with the SDL
library.

%prep
%autosetup -p1 -n sdl12-compat-release-%version

%build
%cmake
%cmake_build

%install
%cmake_install
b="%buildroot"
ln -s sdl12_compat.pc "$b/%_libdir/pkgconfig/sdl.pc"
rm -v "$b/%_libdir"/*.a

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE.txt
%_libdir/libSDL-1.2.so.*

%files devel
%_bindir/sdl-config
%_includedir/SDL/
%_datadir/aclocal/
%_libdir/pkgconfig/*.pc
%_libdir/libSDL*so

%changelog
* Tue Sep 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.68
  * sync dr_mp3 with mainstream
  * Add null check to SDL_LoadWAV_RW to avoid crashes
  * Add quirk entry: deactivate GL scaling for Trine (2011 Humble
    Bundle version) and Mark of the Ninja (HB)
  * Add quirk entry: set Hyperspace Delivery Boy to run in 16bpp mode
  * Add quirk handling: add ability to force XInitThreads before
    main()
  * Allocate the video surface object statically as a global
  * Add a hint to clamp the reported screen bit depth
* Fri May 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.64
  * Some games started working: Steel Storm Burning Retribution,
    Maelstrom, Quake 2 XP, boswars, pink-pony, Sid Meier's Alpha
    Centauri (Loki version), xrick, grafx2, MLT, tuxfootball,
    freedroid.
* Wed Oct 26 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.60
  * SDL_GetWMInfo() now works with SDL2 builds from the 2.0.xx
    revisions.
  * SDL_GetWMInfo() no longer asserts if used on Wayland.
  * SDL_WM_SetIcon() no longer crashes on NULL icons, to match
    SDL-1.2.
  * Make SDL2's OpenGL 2D renderer work with apps that update
    their screen surface from background threads
  * SDL_ANYFORMAT is now supported
  * SDL2 game controllers can optionally be used with the 1.2
    Joystick API.
  * Check for specific X11 symbols in the process at startup and
    force SDL2 to use X11 if so (fixes startup failures on
    Wayland).
- Delete 0001-Use-SDL_PIXELFORMAT_RGB888-for-24-bit-surfaces.patch,
  0001-Set-pixels-in-SDL_CreateYUVOverlay-Fix-164.patch,
  0001-SDL_GetWMInfo-work-like-1.2-when-SDL_SetVideoMode-ha.patch
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Use-SDL_PIXELFORMAT_RGB888-for-24-bit-surfaces.patch
  to rectify BGR order in older schismtracker.
* Wed Jun 15 2022 Jan Engelhardt <jengelh@inai.de>
- Require x11 and xorgproto just like SDL-devel.
* Wed Jun 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Depend on the actual libSDL2 library which is being dlopen()'ed.
- Require pkgconfig(gl) and pkgconfig)glu) from the devel package,
  as our headers include GL/gl.h and GL/glu.h (boo#1200562).
* Tue May 17 2022 Jan Engelhardt <jengelh@inai.de>
- Add baselibs.conf
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-SDL_GetWMInfo-work-like-1.2-when-SDL_SetVideoMode-ha.patch
  to unbreak use with schismtracker.
- Add 0001-Set-pixels-in-SDL_CreateYUVOverlay-Fix-164.patch
  to unbreak use with MPlayer.
- Hot enable sdl12-compat to be the SDL1 replacement [boo#1198182]
* Sat Mar  5 2022 Jan Engelhardt <jengelh@inai.de>
- Initial package (v1.2.52) for build.opensuse.org
